@@ -1,6 +1,8 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010-2011 Aurimas Cernius
+ * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -20,6 +22,7 @@
 
 #include <string.h>
 
+#include <glibmm.h>
 #include <glibmm/i18n.h>
 #include <gtkmm/treemodelsort.h>
 
@@ -188,12 +191,15 @@ namespace gnote {
     bool NotebookManager::get_notebook_iter(const Notebook::Ptr & notebook, 
                                             Gtk::TreeIter & iter)
     {
-      std::string normalized_name = notebook->get_normalized_name();
-      std::map<std::string, Gtk::TreeIter>::iterator map_iter 
-        = m_notebookMap.find (normalized_name);
-      if (map_iter != m_notebookMap.end()) {
-        iter = map_iter->second;
-        return true;
+      Gtk::TreeNodeChildren notebooks = m_sortedNotebooks->children();
+      for (Gtk::TreeIter notebooks_iter = notebooks.begin();
+           notebooks_iter != notebooks.end(); ++notebooks_iter) {
+        Notebook::Ptr current_notebook;
+        notebooks_iter->get_value(0, current_notebook);
+        if (current_notebook == notebook) {
+          iter = notebooks_iter;
+          return true;
+        }
       }
       
       iter = Gtk::TreeIter();
@@ -265,9 +271,9 @@ namespace gnote {
     bool NotebookManager::is_notebook_tag(const Tag::Ptr & tag)
     {
       std::string fullTagName = tag->name();
-      return sharp::string_starts_with(fullTagName, 
-                                       std::string(Tag::SYSTEM_TAG_PREFIX) 
-                                       + Notebook::NOTEBOOK_TAG_PREFIX);
+      return Glib::str_has_prefix(fullTagName,
+                                  std::string(Tag::SYSTEM_TAG_PREFIX)
+                                  + Notebook::NOTEBOOK_TAG_PREFIX);
     }
 
 
@@ -283,8 +289,7 @@ namespace gnote {
       // Prompt the user for the name of a new notebook
       CreateNotebookDialog dialog(parent,
                                   (GtkDialogFlags)(GTK_DIALOG_MODAL
-                                                   | GTK_DIALOG_DESTROY_WITH_PARENT
-                                                   | GTK_DIALOG_NO_SEPARATOR));
+                                                   | GTK_DIALOG_DESTROY_WITH_PARENT));
       
       
       int response = dialog.run ();
@@ -338,11 +343,13 @@ namespace gnote {
       if (response != Gtk::RESPONSE_YES) {
         return;
       }
+
+      // Grab the template note before removing all the notebook tags
+      Note::Ptr templateNote = notebook->get_template_note ();
       
       instance().delete_notebook (notebook);
 
       // Delete the template note
-      Note::Ptr templateNote = notebook->get_template_note ();
       if (templateNote) {
         NoteManager & noteManager(Gnote::obj().default_note_manager());
         noteManager.delete_note (templateNote);
@@ -440,9 +447,9 @@ namespace gnote {
         const Tag::Ptr & tag(*tag_iter);
         // Skip over tags that aren't notebooks
         if (!tag->is_system()
-            || !sharp::string_starts_with(tag->name(),
-                                          std::string(Tag::SYSTEM_TAG_PREFIX)
-                                          + Notebook::NOTEBOOK_TAG_PREFIX)) {
+            || !Glib::str_has_prefix(tag->name(),
+                                     std::string(Tag::SYSTEM_TAG_PREFIX)
+                                     + Notebook::NOTEBOOK_TAG_PREFIX)) {
           continue;
         }
         Notebook::Ptr notebook(new Notebook (tag));
