@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010-2011 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -21,6 +22,7 @@
 
 #include <glibmm/i18n.h>
 #include <gtkmm/imagemenuitem.h>
+#include <gtkmm/separatormenuitem.h>
 
 #include "notebooks/notebooknoteaddin.hpp"
 #include "notebooks/notebookmanager.hpp"
@@ -200,6 +202,9 @@ namespace notebooks {
     noNotebookMenuItem->show_all ();
     m_menu->append (*noNotebookMenuItem);
     m_menu_items.push_back(noNotebookMenuItem);
+
+    NotebookMenuItem *active_menu_item = noNotebookMenuItem;
+    Notebook::Ptr current_notebook = NotebookManager::instance().get_notebook_from_note(get_note());
       
     // Add in all the real notebooks
     std::list<NotebookMenuItem*> notebookMenuItems;
@@ -216,8 +221,12 @@ namespace notebooks {
         item->show_all ();
         m_menu->append (*item);
         m_menu_items.push_back(item);
+        if(current_notebook == item->get_notebook())
+          active_menu_item = item;
       }
     }
+
+    active_menu_item->set_active(true);
   }
   
 
