@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010-2011 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -76,15 +77,18 @@ namespace gnote {
       }
     Note::Ptr find(const std::string &) const;
     Note::Ptr find_by_uri(const std::string &) const;
+    std::string get_unique_name (std::string basename, int id) const;
     void delete_note(const Note::Ptr & note);
 
     Note::Ptr create();
     Note::Ptr create(const std::string & title);
     Note::Ptr create(const std::string & title, const std::string & xml_content);
+    static void replace_body_if_differ(Note::Ptr dest, const Note::Ptr src);
     // Import a note read from file_path
     // Will ensure the sanity including the unique title.
     Note::Ptr import_note(const std::string & file_path);
     Note::Ptr create_with_guid(const std::string & title, std::string & guid);
+    Note::Ptr find_template_note() const;
     Note::Ptr get_or_create_template_note();
     static std::string get_note_template_content(const std::string & title);
     static std::string split_title_from_content (std::string title, std::string & body);
@@ -108,6 +112,7 @@ namespace gnote {
     void create_start_notes();
     void on_note_save(const Note::Ptr & note);
     void load_notes();
+    void migrate_notes(const std::string & old_note_dir);
     void post_load();
     bool first_run() const;
     void create_notes_dir() const;
@@ -126,7 +131,7 @@ namespace gnote {
     Note::List m_notes;
     AddinManager   *m_addin_mgr;
     TrieController *m_trie_controller;
-    std::string m_note_template_title;
+    std::string m_default_note_template_title;
     std::string m_start_note_uri;
     NoteChangedSlot m_signal_start_note_created;
   };
