@@ -61,6 +61,12 @@ namespace gnote {
 
 
 
+  NoteRecentChanges *NoteRecentChanges::get_instance()
+  {
+    return s_instance;
+  }
+
+
   NoteRecentChanges *NoteRecentChanges::get_instance(NoteManager& m)
   {
     if(!s_instance) {
@@ -212,8 +218,8 @@ namespace gnote {
     // until the note's queue_save () kicks in.
     notebooks::NotebookManager::instance().signal_note_added_to_notebook()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_added_to_notebook));
-    notebooks::NotebookManager::instance().signal_note_added_to_notebook()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_removed_to_notebook));
+    notebooks::NotebookManager::instance().signal_note_removed_from_notebook()
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_removed_from_notebook));
                         
     Gtk::Main::signal_quit()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_exiting_event));
@@ -241,7 +247,7 @@ namespace gnote {
     // end notebook addin
     am ["CloseWindowAction"]->signal_activate()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_close_window));
-    if (Gnote::tray_icon_showing() == false)
+    if (Gnote::obj().tray_icon_showing() == false)
       am ["CloseWindowAction"]->set_visible(false);
 
     // Allow Escape to close the window as well as <Control>W
@@ -803,12 +809,7 @@ namespace gnote {
                   
     m_tree->get_path_at_pos (ev->x, ev->y,
                              dest_path, column, unused, unused);
-    // we need to test gobj() isn't NULL.
-    // See Gtkmm bug 586437
-    // https://bugzilla.gnome.org/show_bug.cgi?id=586437
-    if (dest_path.empty() || !dest_path.gobj())
-      return false;
-                  
+
     m_clickX = ev->x;
     m_clickY = ev->y;
                   
@@ -1095,7 +1096,7 @@ namespace gnote {
     hide ();
     delete s_instance;
     s_instance = NULL;
-    if (Gnote::tray_icon_showing() == false) {
+    if (Gnote::obj().tray_icon_showing() == false) {
       ActionManager::obj()["QuitGNoteAction"]->activate();
     }
   }
@@ -1485,26 +1486,10 @@ namespace gnote {
       notebooks::Notebook::Ptr notebook = get_selected_notebook ();
       if (!notebook)
         return true; // Don't pop open a submenu
-          
 
-      bool rowClicked = true;
-      if (m_notebooksTree->get_path_at_pos (ev->x, ev->y, p, col, cell_x, cell_y) == false) {
-        rowClicked = false;
-      }
-      if (selection->count_selected_rows () == 0) {
-        rowClicked = false;
-      }
+      Gtk::Menu *menu = dynamic_cast<Gtk::Menu*>(ActionManager::obj().get_widget (
+                                                 "/NotebooksTreeContextMenu"));
 
-      Gtk::Menu *menu = NULL;
-      if (rowClicked) {
-        menu = dynamic_cast<Gtk::Menu*>(ActionManager::obj().get_widget (
-                                          "/NotebooksTreeContextMenu"));
-      }
-      else {
-        menu = dynamic_cast<Gtk::Menu*>(ActionManager::obj().get_widget (
-                                          "/NotebooksTreeNoRowContextMenu"));
-      }
-          
       popup_context_menu_at_location (menu,
                                       ev->x, ev->y);
       return true;
@@ -1542,7 +1527,7 @@ namespace gnote {
     update_results ();
   }
     
-  void NoteRecentChanges::on_note_removed_to_notebook (const Note & , 
+  void NoteRecentChanges::on_note_removed_from_notebook (const Note & , 
                                                        const notebooks::Notebook::Ptr & )
   {
     update_results ();
