@@ -60,6 +60,7 @@ class NoteRecentChanges
   : public utils::ForcedPresentWindow
 {
 public:
+  static NoteRecentChanges *get_instance();
   static NoteRecentChanges *get_instance(NoteManager& m);
 
   void set_search_text(const std::string & value);
@@ -133,7 +134,7 @@ private:
   bool on_notebooks_tree_button_pressed(GdkEventButton *);
   bool on_notebooks_key_pressed(GdkEventKey *);
   void on_note_added_to_notebook (const Note & note, const notebooks::Notebook::Ptr & notebook);
-  void on_note_removed_to_notebook (const Note & note, const notebooks::Notebook::Ptr & notebook);
+  void on_note_removed_from_notebook (const Note & note, const notebooks::Notebook::Ptr & notebook);
   std::string get_search_text();
   void save_position ();
   void restore_position();
