@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010-2011 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +18,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <boost/format.hpp>
 
@@ -25,6 +28,7 @@
 #include <gtkmm/box.h>
 #include <gtkmm/main.h>
 #include <gtkmm/menuitem.h>
+#include <gtkmm/separatormenuitem.h>
 #include <gtkmm/stock.h>
 
 
@@ -397,13 +401,8 @@ namespace gnote {
     , m_keybinder(new GnotePrefsKeybinder(manager, *this))
     , m_context_menu(NULL)
   {
-    int panel_size = 32;
-    Glib::RefPtr<Gdk::Pixbuf> pixbuf = utils::get_icon("gnote", panel_size);
-    set(pixbuf);
-#if GTK_VERSION_GE(2,16)
     gtk_status_icon_set_tooltip_text(gobj(), 
                                      tray_util_get_tooltip_text().c_str());
-#endif
 
     Gtk::Main::signal_quit().connect(sigc::mem_fun(*this, &TrayIcon::on_exit), 1);
     signal_activate().connect(sigc::mem_fun(*this, &TrayIcon::on_activate));
@@ -533,6 +532,20 @@ namespace gnote {
       return open_upwards;
   }
 
+  bool TrayIcon::on_size_changed(int size)
+  {
+    if(size < 32) {
+      size = 24;
+    }
+    else if(size < 48) {
+      size = 32;
+    }
+    else size = 48;
+    Glib::RefPtr<Gdk::Pixbuf> pixbuf = utils::get_icon("gnote", size);
+    set(pixbuf);
+    return Gtk::StatusIcon::on_size_changed(size);
+  }
+
   //
   // This is a helper to take the XKeybinding string from GConf, and
   // convert it to a widget accelerator label, so note menu items can
