@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2011 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -50,7 +51,6 @@ namespace gnote {
 
     
     void popup_menu(Gtk::Menu &menu, const GdkEventButton *);
-    void popup_menu(Gtk::Menu &menu, const GdkEventButton *, Gtk::Menu::SlotPositionCalc calc);
 
     void show_help(const std::string & filename, const std::string & link_id,
                    GdkScreen *screen, Gtk::Window *parent);
@@ -145,7 +145,7 @@ namespace gnote {
         {
           return m_buffer;
         }
-      const std::string text() const
+      const Glib::ustring text() const
         {
           return start().get_text(end());
         }
@@ -236,7 +236,7 @@ namespace gnote {
       virtual bool on_mnemonic_activate(bool group_cycling);
 
     private:
-      void _common_init(Gtk::Image& image);
+      void _common_init(Gtk::Image& image, const Glib::ustring & l);
       // managed by gtkmm
       Gtk::Menu *m_menu;
       void release_button();        
